@@ -1,5 +1,5 @@
    
-from dagster import DagsterRunStatus, RunsFilter, SkipReason
+from dagster import DagsterRunStatus, RunsFilter
 
 
 def dagster_job_check(context, job_name, jobs_number=1):
@@ -10,7 +10,7 @@ def dagster_job_check(context, job_name, jobs_number=1):
     active_runs = [run for run in runs if run.job_name == job_name and run.status == DagsterRunStatus.STARTED]
     if len(active_runs) > jobs_number:
         # 有正在运行的实例，跳过此次执行
-        context.log.info(f'【当前任务列表】{str(active_runs)}')
+        context.log.info(f'【正在运行:{job_name}.当前任务列表】{str(active_runs)}')
         return False
     context.log.info(f'【当前任务名称】{str(job_name)}')
     return True
@@ -23,7 +23,7 @@ def dagster_sensor_check(context, job_name, jobs_number=1):
     active_runs = [run for run in runs if run.job_name == job_name]
     if len(active_runs) > jobs_number:
         # 有正在运行的实例，跳过此次执行
-        context.log.info(f'【当前任务列表】{str(active_runs)}')
+        context.log.info(f'【正在运行:{job_name}.当前任务列表】{str(active_runs)}')
         return False
     context.log.info(f'【当前任务名称】{str(job_name)}')
     return True
\ No newline at end of file
